@@ -9,7 +9,7 @@ class AboutDlg : public QDialog
 {
     Q_OBJECT
 public:
-    AboutDlg(QWidget *parent);
+    AboutDlg(QWidget *parent = 0);
 };
 
 #endif
