@@ -15,6 +15,7 @@ public:
     RemoteDBMgr();
     ~RemoteDBMgr();
 
+public slots:
     void getDBAsync();
 
 signals:
@@ -30,6 +31,7 @@ private:
 
     RemoteDB db;
     QNetworkAccessManager netAM;
+    bool processing;
 };
 
 #endif
