@@ -11,21 +11,28 @@
 class QHBoxLayout;
 class QListWidget;
 class QListWidgetItem;
+class RemoteTable;
 class QSettings;
 class QNetworkAccessManager;
 class QNetworkReply;
 class QWidget;
 class QPushButton;
 class QLabel;
+class QShowEvent;
+class OnlinePollerThread;
 
 class SelectRemoteDlg : public QDialog
 {
     Q_OBJECT
 
 public:
-    SelectRemoteDlg(QWidget *parent);
+    SelectRemoteDlg(QWidget *parent = 0);
     ~SelectRemoteDlg();
 
+public slots:
+    void refreshDB();
+    void getDB();
+
 private slots:
     void alphabetItemChanged(QListWidgetItem *current,
                              QListWidgetItem *previous);
@@ -36,6 +43,9 @@ private slots:
 signals:
     void remoteChanged(Remote);
 
+protected slots:
+    void showEvent(QShowEvent*);
+
 private:
     RemoteDBMgr remoteDBMgr;
 
@@ -43,9 +53,10 @@ private:
     QHBoxLayout *layout;
     QListWidget *alphabetList;
     QListWidget *mfgList;
-    QListWidget *modelList;
+    RemoteTable *modelList;
     QPushButton *downloadBtn;
     RemoteDB *remoteDB;
+    OnlinePollerThread *onlinePollerThread;
 
     void setBusy(bool busy = true);
 };
