@@ -3,6 +3,7 @@
 
 #include <QDialog>
 #include <QSettings>
+#include <QNetworkConfigurationManager>
 
 #include "remote.h"
 
@@ -19,24 +20,25 @@ class SettingsDlg : public QDialog
 public:
     SettingsDlg(QWidget *parent = 0);
     ~SettingsDlg();
+    void showEvent(class QShowEvent *);
 
 private slots:
     void showAdvSettingsDlg();
     void showSelectRemoteDlg();
     void showAboutDlg();
     void setRemote(Remote);
-    void setRemote(const QString &name);
     void updateRemoteInfo();
     void rateUpClicked();
     void rateDownClicked();
+    void onNetworkStatusUpdate();
 
 private:
     void enableRateBtns(bool enable = true);
-    void processRemoteChange();
     void processRatingSent();
     void setBusy(bool busy = true);
 
 private:
+    bool m_busy;
     Remote m_remote;
 
     QVBoxLayout *m_layout;
@@ -49,6 +51,7 @@ private:
     QPushButton *m_aboutBtn;
     QLabel *m_remoteNameLabel;
     QLabel *m_ratingLabel;
+    QTM_PREPEND_NAMESPACE(QNetworkConfigurationManager) *m_netConfMan;
 };
 
 #endif
