@@ -15,13 +15,15 @@ SettingsTable::~SettingsTable()
 
 void SettingsTable::appendRow(const QString &key, const QString &value)
 {
+    int currentRow = rowCount(); 
     QTableWidgetItem *k = new QTableWidgetItem(key);
     QTableWidgetItem *v = new QTableWidgetItem(value);
     k->setFlags(Qt::NoItemFlags | Qt::ItemIsEnabled);
     v->setFlags(Qt::ItemIsEnabled | Qt::ItemIsEditable);
-    insertRow(rowCount());
-    setItem(rowCount() - 1, 0, k);
-    setItem(rowCount() - 1, 1, v);
+    insertRow(currentRow);
+    setItem(currentRow, 0, k);
+    setItem(currentRow, 1, v);
+    verticalHeader()->resizeSection(currentRow, 60);
 }
 
 void SettingsTable::removeAllRows()
