@@ -1,17 +1,20 @@
-#include <QDebug>
 #include "qnetworkreply.h"
 
+QBuffer QNetworkReply::data;
+
 QNetworkReply::QNetworkReply()
 {
+    data.open(QIODevice::ReadOnly);
 }
 
 QNetworkReply::~QNetworkReply()
 {
+    close();
 }
 
 QByteArray QNetworkReply::readAll()
 {
-    return QByteArray();
+    return data.data();
 }
 
 int QNetworkReply::error() const
@@ -21,6 +24,7 @@ int QNetworkReply::error() const
 
 void QNetworkReply::close()
 {
+    data.close();
 }
 
 void QNetworkReply::deleteLater()
@@ -29,6 +33,7 @@ void QNetworkReply::deleteLater()
 
 QByteArray QNetworkReply::readLine(qint64 maxlen)
 {
-    return QByteArray();
+    return data.readLine(maxlen);
 }
 
+
