@@ -2,6 +2,7 @@
 #define UT_REMOTE_H
 
 #include <QObject>
+#include <QWaitCondition>
 
 class Remote;
 
@@ -17,11 +18,17 @@ private slots:
 
     void testSaveToFile_normal();
     void testSaveToFile_emptyname();
-    void testUpdateInfo();
-    void testSendRating();
+    void testUpdateInfo_normal();
+    void testUpdateInfo_emptyname();
+    void testSendRating_up();
+    void testSendRating_down();
+
+public slots:
+    void wakeTest();
 
 private:
     Remote *subject;
+    QWaitCondition cond;
 };
 
 #endif // UT_REMOTE_H
